# ospyata

![Python](https://ForTheBadge.com/images/badges/made-with-python.svg)
![Built with :heart:](https://ForTheBadge.com/images/badges/built-with-love.svg)

![Maintained](https://img.shields.io/badge/Maintained%3F-yes-green.svg)
![Issues Open](https://img.shields.io/github/issues/aerocyber/ospyata.svg)
![Issues Closed](https://img.shields.io/github/issues-closed/aerocyber/ospyata.svg)
![Pull Requests Open](https://img.shields.io/github/issues-pr/aerocyber/ospyata.svg)
![Pull Requests Closed](https://img.shields.io/github/issues-pr-closed/aerocyber/ospyata)
![Maintainer](https://img.shields.io/badge/maintainer-aerocyber-blue)
[![PyPi version](https://badgen.net/pypi/v/ospyata/)](https://pypi.com/project/ospyata)
[![GitHub license](https://badgen.net/github/license/aerocyber/ospyata)](https://github.com/aerocyber/ospyata/blob/master/LICENSE)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/ospyata.svg)](https://pypi.python.org/pypi/ospyata/)

Python bindings for osmata

## Docs

Visit [Docs](https://aerocyber.github.io/ospyata/docs/) page!

### LICENSE

> MIT License
>
> Copyright (c) 2021 aerocyber
>
> Permission is hereby granted, free of charge, to any person obtaining a copy
> of this software and associated documentation files (the "Software"), to deal
> in the Software without restriction, including without limitation the rights
> to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
> copies of the Software, and to permit persons to whom the Software is
> furnished to do so, subject to the following conditions:
>
> The above copyright notice and this permission notice shall be included in all
> copies or substantial portions of the Software.
>
> THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
> IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
> FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
> AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
> LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
> OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
> SOFTWARE.
